@@ -16,17 +16,19 @@
 # under the License.
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, cast
+from collections.abc import Collection
+from typing import TYPE_CHECKING, Any, cast
 
 from sqlalchemy import func, select, tuple_
 
-from airflow.models import DagBag, DagRun, TaskInstance
+from airflow.models import DagRun, TaskInstance
+from airflow.models.serialized_dag import SerializedDagModel
 from airflow.providers.standard.version_compat import AIRFLOW_V_3_0_PLUS
 from airflow.utils.session import NEW_SESSION, provide_session
 
 if TYPE_CHECKING:
     from sqlalchemy.orm import Session
-    from sqlalchemy.sql import Executable
+    from sqlalchemy.sql import Select
 
 
 @provide_session
@@ -58,6 +60,7 @@ def _get_count(
             session.scalar(
                 _count_stmt(TI, states, dttm_filter, external_dag_id).where(TI.task_id.in_(external_task_ids))
             )
+            or 0
         ) / len(external_task_ids)
     elif external_task_group_id:
         external_task_group_task_ids = _get_external_task_group_task_ids(
@@ -67,20 +70,25 @@ def _get_count(
             count = 0
         else:
             count = (
-                session.scalar(
-                    _count_stmt(TI, states, dttm_filter, external_dag_id).where(
-                        tuple_(TI.task_id, TI.map_index).in_(external_task_group_task_ids)
+                (
+                    session.scalar(
+                        _count_stmt(TI, states, dttm_filter, external_dag_id).where(
+                            tuple_(TI.task_id, TI.map_index).in_(external_task_group_task_ids)
+                        )
                     )
+                    or 0
                 )
                 / len(external_task_group_task_ids)
                 * len(dttm_filter)
             )
     else:
-        count = session.scalar(_count_stmt(DR, states, dttm_filter, external_dag_id))
+        count = session.scalar(_count_stmt(DR, states, dttm_filter, external_dag_id)) or 0
     return cast("int", count)
 
 
-def _count_stmt(model, states, dttm_filter, external_dag_id) -> Executable:
+def _count_stmt(
+    model: type[DagRun] | type[TaskInstance], states: list[str], dttm_filter: list[Any], external_dag_id: str
+) -> Select[tuple[int]]:
     """
     Get the count of records against dttm filter and states.
 
@@ -96,7 +104,9 @@ def _count_stmt(model, states, dttm_filter, external_dag_id) -> Executable:
     )
 
 
-def _get_external_task_group_task_ids(dttm_filter, external_task_group_id, external_dag_id, session):
+def _get_external_task_group_task_ids(
+    dttm_filter: list[Any], external_task_group_id: str, external_dag_id: str, session: Session
+) -> list[tuple[str, int]]:
     """
     Get the count of records against dttm filter and states.
 
@@ -105,7 +115,9 @@ def _get_external_task_group_task_ids(dttm_filter, external_task_group_id, exter
     :param external_dag_id: The ID of the external DAG.
     :param session: airflow session object
     """
-    refreshed_dag_info = DagBag(read_dags_from_db=True).get_dag(external_dag_id, session)
+    refreshed_dag_info = SerializedDagModel.get_dag(external_dag_id, session=session)
+    if not refreshed_dag_info:
+        return [(external_task_group_id, -1)]
     task_group = refreshed_dag_info.task_group_dict.get(external_task_group_id)
 
     if task_group:
@@ -124,3 +136,14 @@ def _get_external_task_group_task_ids(dttm_filter, external_task_group_id, exter
     # returning default task_id as group_id itself, this will avoid any failure in case of
     # 'check_existence=False' and will fail on timeout
     return [(external_task_group_id, -1)]
+
+
+def _get_count_by_matched_states(
+    run_id_task_state_map: dict[str, dict[str, Any]],
+    states: Collection[str],
+):
+    count = 0
+    for _, task_states in run_id_task_state_map.items():
+        if all(state in states for state in task_states.values() if state):
+            count += 1
+    return count
